Enum galvanic_assert::MatchResult
[−]
[src]
pub enum MatchResult {
Matched {
name: String,
},
Failed {
name: String,
reason: String,
},
}The return type of any Machter
Variants
MatchedIndicates that the Matcher matched the value under inspection.
Fields of Matched
name: String | The |
FailedIndicates that the Matcher failed to match the value under inspection.
Fields of Failed
name: String | The |
reason: String | The |