Struct galvanic_assert::matchers::collection::ContainsInOrder
[−]
[src]
pub struct ContainsInOrder<T> { /* fields omitted */ }Matches if the asserted collection contains all and only of the expected elements in the given order.